%global with_doc 0
%{!?upstream_version: %global upstream_version %{version}%{?milestone}}

# Guard for rhosp for packages not supported in OSP
%global rhosp 1

# openstack-packstack ----------------------------------------------------------

Name:           openstack-packstack
Epoch:          1
Version:        12.0.2
Release:        1%{?dist}
Summary:        Openstack Install Utility

Group:          Applications/System
License:        ASL 2.0 and GPLv2
URL:            https://github.com/openstack/packstack
Source0:        https://tarballs.openstack.org/packstack/packstack-%{upstream_version}.tar.gz

# patches_ignore=DROP-IN-RPM
# patches_base=12.0.2

BuildArch:      noarch

BuildRequires:  python2-devel
BuildRequires:  python-setuptools
BuildRequires:  python-pbr
BuildRequires:  git

Requires:       openssh-clients
Requires:       python-netaddr
Requires:       python-netifaces
Requires:       openstack-packstack-puppet == %{epoch}:%{version}-%{release}
Obsoletes:      packstack-modules-puppet
Requires:       PyYAML
Requires:       python-docutils
Requires:       pyOpenSSL >= 16.2.0
Requires:       python-pbr
Requires:       python-setuptools

%description
Packstack is a utility that uses Puppet modules to install OpenStack. Packstack
can be used to deploy various parts of OpenStack on multiple pre installed
servers over ssh.


# openstack-packstack-puppet ---------------------------------------------------

%package puppet
Summary:        Packstack Puppet module
Group:          Development/Libraries

# generated from packstack/Puppetfile:
# awk -F\' '/^mod / {print "Requires: puppet-" $2}' Puppetfile

Requires: puppet-aodh
Requires: puppet-ceilometer
Requires: puppet-cinder
Requires: puppet-glance
Requires: puppet-gnocchi
Requires: puppet-heat
Requires: puppet-horizon
Requires: puppet-ironic
Requires: puppet-keystone
Requires: puppet-manila
Requires: puppet-neutron
Requires: puppet-nova
Requires: puppet-openstack_extras
Requires: puppet-openstacklib
Requires: puppet-oslo
Requires: puppet-ovn
Requires: puppet-panko
Requires: puppet-sahara
Requires: puppet-swift
Requires: puppet-tempest
Requires: puppet-trove
Requires: puppet-vswitch
Requires: puppet-apache
Requires: puppet-certmonger
Requires: puppet-concat
Requires: puppet-firewall
Requires: puppet-inifile
Requires: puppet-memcached
Requires: puppet-mysql
Requires: puppet-nssdb
Requires: puppet-rabbitmq
Requires: puppet-redis
Requires: puppet-remote
Requires: puppet-rsync
Requires: puppet-ssh
Requires: puppet-stdlib
Requires: puppet-sysctl
Requires: puppet-vcsrepo
Requires: puppet-xinetd

%if 0%{rhosp} == 0
Requires: puppet-magnum
%endif

%description puppet
Puppet module used by Packstack to install OpenStack


# openstack-packstack-doc ------------------------------------------------------

%if 0%{?with_doc}
%package doc
Summary:          Documentation for Packstack
Group:            Documentation
BuildRequires:    python-sphinx
BuildRequires:    python-netaddr
BuildRequires:    python-netifaces
BuildRequires:    PyYAML
BuildRequires:    pyOpenSSL

%description doc
This package contains documentation files for Packstack.
%endif


%prep
%autosetup -n packstack-%{upstream_version} -S git

# Sanitizing a lot of the files in the puppet modules
find packstack/puppet/modules \( -name .fixtures.yml -o -name .gemfile -o -name ".travis.yml" -o -name .rspec \) -exec rm {} +
find packstack/puppet/modules \( -name "*.py" -o -name "*.rb" -o -name "*.pl" \) -exec sed -i '/^#!/{d;q}' {} + -exec chmod -x {} +
find packstack/puppet/modules \( -name "*.sh" \) -exec sed -i 's/^#!.*/#!\/bin\/bash/g' {} + -exec chmod +x {} +
find packstack/puppet/modules -name site.pp -size 0 -exec rm {} +
find packstack/puppet/modules \( -name spec -o -name ext \) | xargs rm -rf

# Moving this data directory out temporarily as it causes setup.py to throw errors
rm -rf %{_builddir}/puppet
mv packstack/puppet %{_builddir}/puppet

%build
%py2_build

%if 0%{?with_doc}
%{__python2} setup.py build_sphinx -b man
%endif

%install
%py2_install

# Delete tests
rm -fr %{buildroot}%{python_sitelib}/tests

# Install Puppet module
mkdir -p %{buildroot}/%{_datadir}/openstack-puppet/modules
cp -r %{_builddir}/puppet/modules/packstack  %{buildroot}/%{_datadir}/openstack-puppet/modules/

# Move packstack documentation
mkdir -p %{buildroot}/%{_datadir}/packstack
install -p -D -m 644 docs/packstack.rst %{buildroot}/%{_datadir}/packstack

# Move Puppet manifest templates back to original place
mkdir -p %{buildroot}/%{python_sitelib}/packstack/puppet
mv %{_builddir}/puppet/templates %{buildroot}/%{python_sitelib}/packstack/puppet/

%if 0%{?with_doc}
mkdir -p %{buildroot}%{_mandir}/man1
install -p -D -m 644 docs/build/man/*.1 %{buildroot}%{_mandir}/man1/
%endif

# Remove docs directory
rm -fr %{buildroot}%{python_sitelib}/docs

%files
%doc LICENSE
%{_bindir}/packstack
%{_datadir}/packstack
%{python_sitelib}/packstack
%{python_sitelib}/packstack-*.egg-info

%files puppet
%defattr(644,root,root,755)
%{_datadir}/openstack-puppet/modules/packstack

%if 0%{?with_doc}
%files doc
%{_mandir}/man1/packstack.1.gz
%endif

%changelog
* Mon Nov 04 2019 Alfredo Moralejo <amoralej@rehdat.com> 1:12.0.2-1
- Update to 12.0.2 (rhbz#1768438)

* Thu Jun 13 2019 Alfredo Moralejo <amoralej@redhat.com> 1:12.0.0-7
- Add OS_REGION_NAME when keystone api is >= 2 in rc file (rhbz#1720173)

* Fri Jan 25 2019 Steve Linabery <slinaber@redhat.com> 1:12.0.0-6
- Set metadata_host instead of metadata_ip

* Wed Nov 21 2018 Jon Schlueter <jschluet@redhat.com> 1:12.0.0-5
- Change file ownership and group to nova (rhbz#1624709)

* Mon Oct 15 2018 Steve Linabery <slinaber@redhat.com> 1:12.0.0-4
- Pin r10k to version 2.6.4
- Use SSL options from nova::

* Tue Jul 24 2018 Jon Schlueter <jschluet@redhat.com> 1:12.0.0-3
- Temporary switch to ovs in scenario 001, fix gate

* Sat Apr 14 2018 Alfredo Moralejo <amoralej@redhat.com> 1:12.0.0-2
- Added python-setuptools as requirement.

* Mon Mar 26 2018 Alan Pevec <apevec AT redhat.com> 1:12.0.0-1
- Update to 12.0.0

* Tue Feb 20 2018 RDO <dev@lists.rdoproject.org> 1:12.0.0-0.1.0rc2
- Update to 12.0.0.0rc2

